DialerConfig class

Constructors

DialerConfig({required List<DialerSlot> items, void onItemPressed(int index)?, TextStyle? labelTextStyle, Color? actionBackgroundColor, double? actionRadius, Color? fabColor, IconData? fabIcon, Color? dialBorderColor, Color? dialOverlayColor, double? dialBlurSigma})
const

Properties

actionBackgroundColor Color?
final
actionRadius double?
final
dialBlurSigma double?
final
dialBorderColor Color?
final
dialOverlayColor Color?
final
fabColor Color?
final
fabIcon IconData?
final
hashCode int
The hash code for this object.
no setterinherited
items List<DialerSlot>
final
labelTextStyle TextStyle?
final
onItemPressed → void Function(int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited